@@ -1,15 +1,15 @@
 <?php
 
 /**
- * decode/iso8859-3.php
+ * decode/iso8859-4.php
  *
- * This file contains iso-8859-3 decoding function that is needed to read
- * iso-8859-3 encoded mails in non-iso-8859-3 locale.
+ * This file contains iso-8859-4 decoding function that is needed to read
+ * iso-8859-4 encoded mails in non-iso-8859-4 locale.
  *
  * Original data taken from:
- *  ftp://ftp.unicode.org/Public/MAPPINGS/ISO8859/8859-3.TXT
+ *  ftp://ftp.unicode.org/Public/MAPPINGS/ISO8859/8859-4.TXT
  *
- *   Name:             ISO/IEC 8859-3:1999 to Unicode
+ *   Name:             ISO/IEC 8859-4:1998 to Unicode
  *   Unicode version:  3.0
  *   Table version:    1.0
  *   Table format:     Format A
@@ -35,114 +35,121 @@
  *
  * @copyright 2003-2026 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: iso_8859_3.php 15041 2026-01-15 10:52:11Z pdontthink $
+ * @version $Id: iso_8859_4.php 15041 2026-01-15 10:52:11Z pdontthink $
  * @package squirrelmail
  * @subpackage decode
  */
 
 /**
- * Decode iso8859-3 encoded string
+ * Decode iso8859-4 string
  * @param string $string Encoded string
  * @return string $string Decoded string
  */
-function charset_decode_iso_8859_3 ($string) {
+function charset_decode_iso_8859_4 ($string) {
     // don't do decoding when there are no 8bit symbols
-    if (! sq_is8bit($string,'iso-8859-3'))
+    if (! sq_is8bit($string,'iso-8859-4'))
         return $string;
 
-    $iso8859_3 = array(
+    $iso8859_4 = array(
         "\xA0" => '&#160;',
-        "\xA1" => '&#294;',
-        "\xA2" => '&#728;',
-        "\xA3" => '&#163;',
+        "\xA1" => '&#260;',
+        "\xA2" => '&#312;',
+        "\xA3" => '&#342;',
         "\xA4" => '&#164;',
-        "\xA6" => '&#292;',
+        "\xA5" => '&#296;',
+        "\xA6" => '&#315;',
         "\xA7" => '&#167;',
         "\xA8" => '&#168;',
-        "\xA9" => '&#304;',
-        "\xAA" => '&#350;',
-        "\xAB" => '&#286;',
-        "\xAC" => '&#308;',
+        "\xA9" => '&#352;',
+        "\xAA" => '&#274;',
+        "\xAB" => '&#290;',
+        "\xAC" => '&#358;',
         "\xAD" => '&#173;',
-        "\xAF" => '&#379;',
+        "\xAE" => '&#381;',
+        "\xAF" => '&#175;',
         "\xB0" => '&#176;',
-        "\xB1" => '&#295;',
-        "\xB2" => '&#178;',
-        "\xB3" => '&#179;',
+        "\xB1" => '&#261;',
+        "\xB2" => '&#731;',
+        "\xB3" => '&#343;',
         "\xB4" => '&#180;',
-        "\xB5" => '&#181;',
-        "\xB6" => '&#293;',
-        "\xB7" => '&#183;',
+        "\xB5" => '&#297;',
+        "\xB6" => '&#316;',
+        "\xB7" => '&#711;',
         "\xB8" => '&#184;',
-        "\xB9" => '&#305;',
-        "\xBA" => '&#351;',
-        "\xBB" => '&#287;',
-        "\xBC" => '&#309;',
-        "\xBD" => '&#189;',
-        "\xBF" => '&#380;',
-        "\xC0" => '&#192;',
+        "\xB9" => '&#353;',
+        "\xBA" => '&#275;',
+        "\xBB" => '&#291;',
+        "\xBC" => '&#359;',
+        "\xBD" => '&#330;',
+        "\xBE" => '&#382;',
+        "\xBF" => '&#331;',
+        "\xC0" => '&#256;',
         "\xC1" => '&#193;',
         "\xC2" => '&#194;',
+        "\xC3" => '&#195;',
         "\xC4" => '&#196;',
-        "\xC5" => '&#266;',
-        "\xC6" => '&#264;',
-        "\xC7" => '&#199;',
-        "\xC8" => '&#200;',
+        "\xC5" => '&#197;',
+        "\xC6" => '&#198;',
+        "\xC7" => '&#302;',
+        "\xC8" => '&#268;',
         "\xC9" => '&#201;',
-        "\xCA" => '&#202;',
+        "\xCA" => '&#280;',
         "\xCB" => '&#203;',
-        "\xCC" => '&#204;',
+        "\xCC" => '&#278;',
         "\xCD" => '&#205;',
         "\xCE" => '&#206;',
-        "\xCF" => '&#207;',
-        "\xD1" => '&#209;',
-        "\xD2" => '&#210;',
-        "\xD3" => '&#211;',
+        "\xCF" => '&#298;',
+        "\xD0" => '&#272;',
+        "\xD1" => '&#325;',
+        "\xD2" => '&#332;',
+        "\xD3" => '&#310;',
         "\xD4" => '&#212;',
-        "\xD5" => '&#288;',
+        "\xD5" => '&#213;',
         "\xD6" => '&#214;',
         "\xD7" => '&#215;',
-        "\xD8" => '&#284;',
-        "\xD9" => '&#217;',
+        "\xD8" => '&#216;',
+        "\xD9" => '&#370;',
         "\xDA" => '&#218;',
         "\xDB" => '&#219;',
         "\xDC" => '&#220;',
-        "\xDD" => '&#364;',
-        "\xDE" => '&#348;',
+        "\xDD" => '&#360;',
+        "\xDE" => '&#362;',
         "\xDF" => '&#223;',
-        "\xE0" => '&#224;',
+        "\xE0" => '&#257;',
         "\xE1" => '&#225;',
         "\xE2" => '&#226;',
+        "\xE3" => '&#227;',
         "\xE4" => '&#228;',
-        "\xE5" => '&#267;',
-        "\xE6" => '&#265;',
-        "\xE7" => '&#231;',
-        "\xE8" => '&#232;',
+        "\xE5" => '&#229;',
+        "\xE6" => '&#230;',
+        "\xE7" => '&#303;',
+        "\xE8" => '&#269;',
         "\xE9" => '&#233;',
-        "\xEA" => '&#234;',
+        "\xEA" => '&#281;',
         "\xEB" => '&#235;',
-        "\xEC" => '&#236;',
+        "\xEC" => '&#279;',
         "\xED" => '&#237;',
         "\xEE" => '&#238;',
-        "\xEF" => '&#239;',
-        "\xF1" => '&#241;',
-        "\xF2" => '&#242;',
-        "\xF3" => '&#243;',
+        "\xEF" => '&#299;',
+        "\xF0" => '&#273;',
+        "\xF1" => '&#326;',
+        "\xF2" => '&#333;',
+        "\xF3" => '&#311;',
         "\xF4" => '&#244;',
-        "\xF5" => '&#289;',
+        "\xF5" => '&#245;',
         "\xF6" => '&#246;',
         "\xF7" => '&#247;',
-        "\xF8" => '&#285;',
-        "\xF9" => '&#249;',
+        "\xF8" => '&#248;',
+        "\xF9" => '&#371;',
         "\xFA" => '&#250;',
         "\xFB" => '&#251;',
         "\xFC" => '&#252;',
-        "\xFD" => '&#365;',
-        "\xFE" => '&#349;',
+        "\xFD" => '&#361;',
+        "\xFE" => '&#363;',
         "\xFF" => '&#729;'
     );
 
-    $string = str_replace(array_keys($iso8859_3), array_values($iso8859_3), $string);
+    $string = str_replace(array_keys($iso8859_4), array_values($iso8859_4), $string);
 
     return $string;
 }
